Enum august_build::runtime::cli::CLICommand
source · pub enum CLICommand {
Info,
Test {
script: Option<PathBuf>,
quiet: bool,
},
Build {
script: Option<PathBuf>,
quiet: bool,
},
Run {
script: Option<PathBuf>,
task_name: String,
quiet: bool,
},
Check {
script: Option<PathBuf>,
},
Inspect {
script: Option<PathBuf>,
},
Completions {
shell: Shell,
},
}Variants
Info
Provides more specific information about the installation
Test
Fields
Runs the task assigned to the test pragma
Build
Fields
Runs the task assigned to the build pragma
Run
Fields
Runs the task provided as an argument
Check
Parses the build script and associated modules to check for errors, but doesn’t run anything
Inspect
Parses the build script and associated modules and displays some details about it. Doesn’t run anything.
Completions
Generate command line autocompletions based on shell